@@ -108,8 +108,9 @@ def parse_head_type(head):
 
 
 def parse_head_pron(head):
-    w_pron_uk = head.find("span", "uk dpron-i").find("span", "pron dpron").text
-    w_pron_uk = replace_all(w_pron_uk)
+    w_pron_uk = head.find("span", "uk dpron-i").find("span", "pron dpron")
+    if w_pron_uk:
+        w_pron_uk = replace_all(w_pron_uk.text)
     # In bs4, not found element returns None, not raise error, so try block is not right
     w_pron_us = head.find("span", "us dpron-i").find("span", "pron dpron")
     if w_pron_us:
@@ -171,7 +172,8 @@ def parse_dict_head(block):
             console.print("[bold #3C8DAD on #DDDDDD]" + word)
 
         if head.find("span", "uk dpron-i"):
-            parse_head_pron(head)
+            if head.find("span", "uk dpron-i").find("span", "pron dpron"):
+                parse_head_pron(head)
 
         if head.find("span", "irreg-infls dinfls"):
             parse_head_tense(head)
@@ -221,13 +223,27 @@ def parse_def_info(def_block):
 
 
 def parse_meaning(def_block):
-    meaning = replace_all(def_block.find("div", "def ddef_d db").text)
-    console.print("[#F5A962]" + meaning)
+    meaning_b = def_block.find("div", "def ddef_d db")
+    if meaning_b.find("span", "lab dlab"):
+        usage_b = meaning_b.find("span", "lab dlab")
+        usage = replace_all(usage_b.text)
+        meaning_words = replace_all(meaning_b.text).split(usage)[-1]
+        console.print(usage + "[#F5A962]" + meaning_words)
+    else:
+        meaning_words = replace_all(meaning_b.text)
+        console.print("[#F5A962]" + meaning_words)
 
 
 def parse_pmeaning(def_block):
-    meaning = replace_all(def_block.find("div", "def ddef_d db").text)
-    console.print("[#F5A962]" + "  " + meaning)
+    meaning_b = def_block.find("div", "def ddef_d db")
+    if meaning_b.find("span", "lab dlab"):
+        usage_b = meaning_b.find("span", "lab dlab")
+        usage = replace_all(usage_b.text)
+        meaning_words = replace_all(meaning_b.text).split(usage)[-1]
+        console.print(usage + "[#F5A962]" + meaning_words)
+    else:
+        meaning_words = replace_all(meaning_b.text)
+        console.print("[#F5A962]" + meaning_words)
 
 
 def parse_example(def_block):
